aboutsummaryrefslogtreecommitdiffstats
path: root/tools/search_tavily.sh
diff options
context:
space:
mode:
Diffstat (limited to 'tools/search_tavily.sh')
-rwxr-xr-xtools/search_tavily.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/tools/search_tavily.sh b/tools/search_tavily.sh
index 13a8520..fb1e367 100755
--- a/tools/search_tavily.sh
+++ b/tools/search_tavily.sh
@@ -5,7 +5,7 @@ set -e
# Use this when you need current information or feel a search could provide a better answer.
# @env TAVILY_API_KEY! The api key
# @env TAVILY_MAX_RESULTS=5 The max results to return.
# @option --query! The query to search for.
main() {
@@ -16,9 +16,9 @@ main() {
"api_key": "'"$TAVILY_API_KEY"'",
"query": "'"$argc_query"'",
"search_depth": "advanced",
- "max_results": "'"$TAVILY_MAX_RESULTS"'"
+ "max_results": "'"$SEARCH_MAX_RESULTS"'"
}' | \
- jq '[.results[] | {title: .title, url: .url, content: .content}]' \
+ jq '[.results[] | {link: .url, title: .title, snippet: .content}]' \
>> "$LLM_OUTPUT"
}
@@ -5,7 +5,7 @@ set -e
# Use this when you need current information or feel a search could provide a better answer.
# @env TAVILY_API_KEY! The api key
-# @env TAVILY_MAX_RESULTS=5 The max results to return.
+# @env SEARCH_MAX_RESULTS=5 The max results to return.
# @option --query! The query to search for.
main() {